==> nextcloud-26.0.10.tgz: nextcloud/apps/logreader/l10n/eu.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Erregistroa",
    "Log Reader" : "Log irakurgailua",
    "A log reader for Nextcloud" : "Nextcloudentzat log fitxategien irakurgailua",
    "Log reader for Nextcloud" : "Nextcloudentzat log fitxategien irakurgailua",
    "Log reader" : "Log irakurgailua",
    "Open log reader settings" : "Ireki log irakurgailuaren ezarpenak",
    "Log reader settings" : "Log irakurgailuaren ezarpenak",
    "Currently the log file {file} is shown" : "Une honetan {file} log fitxategia dago erakusgai",
    "Show server log" : "Erakutsi zerbitzariko erregistroak",
    "Live view is disabled" : "Zuzeneko bistaratzea deagaituta dago",
    "No log file" : "Ez dago log fitxategirik",
    "File-based logging must be enabled to access logs from the Web UI." : "Fitxategi-oinarridun erregistroen aukerak gaituta egon behar du, Web UI bidez erregistroak atzitzeko.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Hau errore bat dela iruditzen bazaizu, begiratu {setting} zure {config} orrian eta aztertu Nextcloud Administratzaile Eskuliburua.",
    "Level" : "Maila",
    "App" : "App",
    "No app in context" : "Ez dago aplikaziorik testuinguruan",
    "Time" : "Noiz",
    "Copy raw entry" : "Kopiatu sarrera gordina",
    "Copy formatted entry" : "Kopiatu formatudun sarrera",
    "Hide exception details" : "Ezkutatu salbuespenaren xehetasunak",
    "View exception details" : "Ikusi salbuespenaren xehetasunak",
    "Raw log entry" : "Log sarrera gordina",
    "Log entry successfully copied" : "Log sarrera ondo kopiatuta",
    "Search log entries" : "Bilatu log sarrerak",
    "Caused by {exception}" : "{exception} sortua",
    "Line {line}" : "{line}. lerroa",
    "Filter log levels" : "Iragazi log mailak",
    "Time format" : "Ordu formatua",
    "Live view" : "Zuzeneko bistaratzea",
    "Download logs" : "Deskargatu log fitxategiak",
    "Show local log file" : "Erakutsi log fitxategi lokala",
    "Upload local log file to be displayed" : "Igo lokaleko log fitxategia, bistaratzeko",
    "Raw data" : "Datu gordinak",
    "Local time" : "Ordu lokala",
    "UTC time" : "UTC ordua",
    "Time format used for displaying the timestamp" : "Denbora-zigilua erakusteko denbora formatua",
    "(Local log files only support the \"raw\" time format)" : "(Log fitxategi lokalek ordu formatu \"gordina\" bakarrik onartzen dute)",
    "Could not change date time format." : "Ezin izan da data ordu formatua aldatu.",
    "Polling is disabled because server is not configured to log to file" : "Informazio eskaera desgaituta dago zerbitzaria ez dagoelako fitxategi batera erregistratzeko konfiguratuta",
    "Polling (live view)" : "Informazio eskaera (zuzeneko ikuspegia)",
    "Could not change live view setting." : "Ezin izan da zuzeneko bistaratzearen ezarpena aldatu",
    "Filter logging levels" : "Iragazi erregistro mailak",
    "Could not set logging levels to show" : "Ezin izan dira erregistro mailak ezarri erakusteko",
    "Application" : "Aplikazioa",
    "Message" : "Mezua",
    "Log entry actions" : "Log sarreren ekintzak",
    "Loading older log entries" : "Log sarrera zaharragoak kargatzen",
    "No older log entries available" : "Ez dago log sarrera zaharragorik eskuragarri",
    "Collapse row" : "Tolestu ilara",
    "Expand row" : "Zabaldu ilara",
    "Show details" : "Erakutsi xehetasunak",
    "Debug" : "Arazketa",
    "Info" : "Informazioa",
    "Warning" : "Abisua",
    "Error" : "Errorea",
    "Fatal" : "Larria",
    "Could not fetch new log entries (server unavailable)" : "Ezin izan da log sarrera berririk eskuratu (zerbitzaria ez dago erabilgarri)",
    "Could not fetch new entries" : "Ezin izan da sarrera berririk eskuratu",
    "Could not copy to clipboard, please copy manually:" : "Ezin izan da arbelera kopiatu, mesedez kopiatu eskuz:",
    "\tfrom {address} by {user} at {time}\n" : "\t{address}(e)tik {user}(r)engatik {time} unean\n",
    "Error parsing log" : "Errorea log fitxategia irakurtzean",
    "Caused by " : "Arrazoia",
    "Copy" : "Kopiatu",
    "Copy raw" : "Kopiatu gordin",
    "Copy formatted" : "Kopiatu formatuarekin",
    "No server logs" : "Ez dago zerbitzariaren log fitxategirik",
    "One or more entries are hidden by the log level filter" : "Log mailaren filtroak sarrera bat edo gehiago ezkutatzen du",
    "Everything is working fine" : "Dena ondo dabil",
    "Load log file" : "Kargatu log fitxategia",
    "Invalid log file" : "Log fitxategi baliogabea",
    "Log levels" : "Log mailak",
    "Log content" : "Log edukia",
    "Live update" : "Etengabeko eguneraketa ",
    "line {line}" : "{line} lerroa",
    "Download / Upload logs" : "Deskargatu / Igo erregistroak"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.2.tgz: nextcloud/apps/logreader/l10n/eu.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Erregistroa",
    "Log Reader" : "Log irakurgailua",
    "A log reader for Nextcloud" : "Nextcloudentzat log fitxategien irakurgailua",
    "Log reader for Nextcloud" : "Nextcloudentzat log fitxategien irakurgailua",
    "Log reader" : "Log irakurgailua",
    "Open log reader settings" : "Ireki log irakurgailuaren ezarpenak",
    "Log reader settings" : "Log irakurgailuaren ezarpenak",
    "Currently the log file {file} is shown" : "Une honetan {file} log fitxategia dago erakusgai",
    "Show server log" : "Erakutsi zerbitzariko erregistroak",
    "Live view is disabled" : "Zuzeneko bistaratzea deagaituta dago",
    "No log file" : "Ez dago log fitxategirik",
    "File-based logging must be enabled to access logs from the Web UI." : "Fitxategi-oinarridun erregistroen aukerak gaituta egon behar du, Web UI bidez erregistroak atzitzeko.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Hau errore bat dela iruditzen bazaizu, begiratu {setting} zure {config} orrian eta aztertu Nextcloud Administratzaile Eskuliburua.",
    "Level" : "Maila",
    "App" : "App",
    "No app in context" : "Ez dago aplikaziorik testuinguruan",
    "Time" : "Noiz",
    "Copy raw entry" : "Kopiatu sarrera gordina",
    "Copy formatted entry" : "Kopiatu formatudun sarrera",
    "Hide exception details" : "Ezkutatu salbuespenaren xehetasunak",
    "View exception details" : "Ikusi salbuespenaren xehetasunak",
    "Raw log entry" : "Log sarrera gordina",
    "Log entry successfully copied" : "Log sarrera ondo kopiatuta",
    "Search log entries" : "Bilatu log sarrerak",
    "Caused by {exception}" : "{exception} sortua",
    "line {line}" : "{line} lerroa",
    "Filter log levels" : "Iragazi log mailak",
    "Time format" : "Ordu formatua",
    "Live view" : "Zuzeneko bistaratzea",
    "Download / Upload logs" : "Deskargatu / Kargatu erregistroak",
    "Download logs" : "Deskargatu log fitxategiak",
    "Show local log file" : "Erakutsi log fitxategi lokala",
    "Upload local log file to be displayed" : "Kargatu lokaleko log fitxategia, bistaratzeko",
    "Raw data" : "Datu gordinak",
    "Local time" : "Ordu lokala",
    "UTC time" : "UTC ordua",
    "Time format used for displaying the timestamp" : "Denbora-zigilua erakusteko denbora formatua",
    "(Local log files only support the \"raw\" time format)" : "(Log fitxategi lokalek ordu formatu \"gordina\" bakarrik onartzen dute)",
    "Could not change date time format." : "Ezin izan da data ordu formatua aldatu.",
    "Polling is disabled because server is not configured to log to file" : "Informazio eskaera desgaituta dago zerbitzaria ez dagoelako fitxategi batera erregistratzeko konfiguratuta",
    "Polling (live view)" : "Informazio eskaera (zuzeneko ikuspegia)",
    "Could not change live view setting." : "Ezin izan da zuzeneko bistaratzearen ezarpena aldatu",
    "Filter logging levels" : "Iragazi erregistro mailak",
    "Could not set logging levels to show" : "Ezin izan dira erregistro mailak ezarri erakusteko",
    "Application" : "Aplikazioa",
    "Message" : "Mezua",
    "Log entry actions" : "Log sarreren ekintzak",
    "Loading older log entries" : "Log sarrera zaharragoak kargatzen",
    "No older log entries available" : "Ez dago log sarrera zaharragorik eskuragarri",
    "Collapse row" : "Tolestu ilara",
    "Expand row" : "Zabaldu ilara",
    "Show details" : "Erakutsi xehetasunak",
    "Debug" : "Arazketa",
    "Info" : "Informazioa",
    "Warning" : "Abisua",
    "Error" : "Errorea",
    "Fatal" : "Larria",
    "Could not fetch new log entries (server unavailable)" : "Ezin izan da log sarrera berririk eskuratu (zerbitzaria ez dago erabilgarri)",
    "Could not fetch new entries" : "Ezin izan da sarrera berririk eskuratu",
    "Could not copy to clipboard, please copy manually:" : "Ezin izan da arbelera kopiatu, mesedez kopiatu eskuz:",
    "\tfrom {address} by {user} at {time}\n" : "\t{address}(e)tik {user}(r)engatik {time} unean\n",
    "Error parsing log" : "Errorea log fitxategia irakurtzean",
    "Caused by " : "Arrazoia",
    "Copy" : "Kopiatu",
    "Copy raw" : "Kopiatu gordin",
    "Copy formatted" : "Kopiatu formatuarekin",
    "No server logs" : "Ez dago zerbitzariaren log fitxategirik",
    "One or more entries are hidden by the log level filter" : "Log mailaren filtroak sarrera bat edo gehiago ezkutatzen du",
    "Everything is working fine" : "Dena ondo dabil",
    "Load log file" : "Kargatu log fitxategia",
    "Invalid log file" : "Log fitxategi baliogabea",
    "Log levels" : "Log mailak",
    "Log content" : "Log edukia",
    "Live update" : "Etengabeko eguneraketa "
},
"nplurals=2; plural=(n != 1);");
